Class: Covered::Base
- Inherits:
-
Object
- Object
- Covered::Base
- Defined in:
- lib/covered/wrapper.rb
Overview
The base coverage output interface.
Instance Method Summary collapse
-
#accept?(path) ⇒ Boolean
Whether the given path should be accepted.
-
#add(coverage) ⇒ Object
Add a coverage object.
-
#clear ⇒ Object
Discard any coverage data and restart tracking.
-
#each ⇒ Object
Enumerate the coverage data.
-
#expand_path(path) ⇒ Object
Expand a path relative to this output.
-
#finish ⇒ Object
Stop tracking coverage.
-
#mark(path, lineno, value) ⇒ Object
Mark coverage for the given path and line number.
-
#relative_path(path) ⇒ Object
Convert a path to a relative path.
-
#start ⇒ Object
Start tracking coverage.
Instance Method Details
#accept?(path) ⇒ Boolean
Whether the given path should be accepted.
24 25 26 |
# File 'lib/covered/wrapper.rb', line 24 def accept?(path) true end |
#add(coverage) ⇒ Object
Add a coverage object.
37 38 |
# File 'lib/covered/wrapper.rb', line 37 def add(coverage) end |
#clear ⇒ Object
Discard any coverage data and restart tracking.
14 15 |
# File 'lib/covered/wrapper.rb', line 14 def clear end |
#each ⇒ Object
Enumerate the coverage data.
43 44 |
# File 'lib/covered/wrapper.rb', line 43 def each end |
#expand_path(path) ⇒ Object
Expand a path relative to this output.
56 57 58 |
# File 'lib/covered/wrapper.rb', line 56 def (path) path end |
#finish ⇒ Object
Stop tracking coverage.
18 19 |
# File 'lib/covered/wrapper.rb', line 18 def finish end |
#mark(path, lineno, value) ⇒ Object
Mark coverage for the given path and line number.
32 33 |
# File 'lib/covered/wrapper.rb', line 32 def mark(path, lineno, value) end |
#relative_path(path) ⇒ Object
Convert a path to a relative path.
49 50 51 |
# File 'lib/covered/wrapper.rb', line 49 def relative_path(path) path end |
#start ⇒ Object
Start tracking coverage.
10 11 |
# File 'lib/covered/wrapper.rb', line 10 def start end |