Exception: Covered::CoverageError
- Inherits:
-
StandardError
- Object
- StandardError
- Covered::CoverageError
- Defined in:
- lib/covered/statistics.rb
Overview
Raised when coverage does not meet the configured minimum.
Raised when coverage does not meet the configured minimum.