Class: Covered::Forks
Overview
Tracks coverage across forked child processes.
Instance Attribute Summary
Attributes inherited from Wrapper
Instance Method Summary collapse
-
#finish ⇒ Object
Stop tracking coverage and remove the fork handler state.
-
#start ⇒ Object
Start tracking coverage and install the fork handler.
Methods inherited from Wrapper
#accept?, #add, #clear, #each, #expand_path, #initialize, #mark, #relative_path, #to_h
Methods inherited from Base
#accept?, #add, #clear, #each, #expand_path, #mark, #relative_path
Constructor Details
This class inherits a constructor from Covered::Wrapper
Instance Method Details
#finish ⇒ Object
Stop tracking coverage and remove the fork handler state.
19 20 21 22 23 |
# File 'lib/covered/forks.rb', line 19 def finish Handler.finish super end |
#start ⇒ Object
Start tracking coverage and install the fork handler.
12 13 14 15 16 |
# File 'lib/covered/forks.rb', line 12 def start super Handler.start(self) end |